Brightway2 life cycle assessment framework
==========================================

Brightway2 is a framework for advanced life cycle assessment calculations. It consists of several components which each accomplish specific tasks. This package is a container for all the separate components, for ease of documentation and installation.

Brightway2 is inspired by the Brightway software, which was developed during Chris Mutel's PhD work at ETH Zurich, but is a complete rewrite focusing on simplicity, power, and ease of use. Brightway2 can run on all major operating systems.

Official site:

* https://brightwaylca.org

Online documentation:

* https://docs.brightwaylca.org/

Development blog:

* http://chris.mutel.org

Packages:

* brightway2-data: https://bitbucket.org/cmutel/brightway2-data
* brightway2-calc: https://bitbucket.org/cmutel/brightway2-calc
* brightway2-analyzer: https://bitbucket.org/cmutel/brightway2-analyzer
* brightway2-ui: https://bitbucket.org/cmutel/brightway2-ui
